package modelo;
import android.content.ContentValues;
import android.content.Context;
import android.content.CursorLoader;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;
import bbdd.PillControlDbHelper;

import java.util.ArrayList;




public class MedicinaDbAdapter {

	//
	// Definimos constante con el nombre de la tabla
	//
	public static final String C_TABLA = "MEDICINA" ;
	
    //
    // Definimos constantes con el nombre de las columnas de la tabla
    //
    public static final String C_COLUMNA_ID	= "_id";
    public static final String C_COLUMNA_NOMBRE = "hip_nombre";
    public static final String C_COLUMNA_DESCRIPCION = "hip_descripcion";
    public static final String C_COLUMNA_TOMARCADA = "hip_tomarCada";
    public static final String C_COLUMNA_EFECTOSSECUNDARIOS = "hip_efectosSecundarios";
    public static final String C_COLUMNA_OBSERVACIONES = "hip_observaciones";
    public static final String C_COLUMNA_DURACION = "hip_duracion";
    public static final String C_COLUMNA_HORAINICIO = "hip_horaInicio";
    public static final String C_COLUMNA_CANTIDAD = "hip_cantidad";
    public static final String C_COLUMNA_ULTIMAGENERACION = "hip_ultimaGeneracion";
    public static final String C_COLUMNA_ULTIMAHORA = "hip_ultimaHora";
    public static final String C_COLUMNA_FINICIO = "hip_fechaInicio";
    public static final String C_COLUMNA_CRONICO = "hip_cronico";
  
    
    
    
    private Context contexto;
    private PillControlDbHelper dbHelper;
    private SQLiteDatabase db;

    //
    // Definimos lista de columnas de la tabla para utilizarla en las consultas a la base de datos
    //
    private String[] columnas = new String[]{
    		C_COLUMNA_ID,	
    	      C_COLUMNA_NOMBRE, 
    	     C_COLUMNA_DESCRIPCION,
    	     C_COLUMNA_TOMARCADA, 
    	     C_COLUMNA_EFECTOSSECUNDARIOS, 
    	     C_COLUMNA_OBSERVACIONES, 
    	     C_COLUMNA_DURACION, 
    	    C_COLUMNA_HORAINICIO, 
    	    C_COLUMNA_CANTIDAD,
    	    C_COLUMNA_CRONICO,
    	    C_COLUMNA_ULTIMAGENERACION,
    	    C_COLUMNA_ULTIMAHORA,
    	    C_COLUMNA_FINICIO,
        
    };
	public MedicinaDbAdapter(Context context)
	{
		this.contexto = context;
	}

	public MedicinaDbAdapter abrir() throws SQLException
	{
		// System.out.println ("LLamada a medicina db helper ");
		
		dbHelper = new PillControlDbHelper(contexto);
			
		db = dbHelper.getWritableDatabase();
	
		
		return this;
	}

	public void cerrar()
	{
		dbHelper.close();
	}

	
    /**
     * Devuelve cursor con todos los registros y columnas de la tabla
     */
    public Cursor getCursor(String filtro) throws SQLException {

        if (db == null)
        abrir();
        Cursor c; 
        try{
        	 c = db.query(true, C_TABLA, columnas, filtro, null, null, null, null, null);
        }
        finally {
            //Casca
        }

        
        return c;
    }
	
	/**
	 * Devuelve cursor con todos las columnas del registro
	 */
	public Cursor getRegistro(long id) throws SQLException
	{
		//System.out.println ("llego a getRegistro");
        if (db == null){
        	
          abrir();
        }

        Cursor c = db.query( true, C_TABLA, columnas, C_COLUMNA_ID + "=" + id, null, null, null, null, null);
    
		if (c != null) {
			c.moveToFirst();
		}
		return c;
	}
	
	/**
	 * Inserta los valores en un registro de la tabla
	 */
	public long insert(ContentValues reg)
	{
		if (db == null)
			abrir();
		
		return db.insert(C_TABLA, null, reg);
	}
	
	/**
	 * Eliminar el registro con el identificador indicado
	 */
	public long delete(long id)
	{
		if (db == null)
	 abrir();
		
		return db.delete(C_TABLA, "_id=" + id, null);
	}
	/*public long deleteNombre(String nombre)
	{
		if (db == null)
	 abrir();
		
		return db.delete(C_TABLA, "hip_nombre LIKE" + nombre, null);
	}*/
	
    /**
     * Modificar el registro
     */
    public long update(ContentValues reg)
    {
        long result = 0;

        if (db == null)
            abrir();

        if (reg.containsKey(C_COLUMNA_ID))
        {
            //
            // Obtenemos el id y lo borramos de los valores
            //
            long id = reg.getAsLong(C_COLUMNA_ID);

            reg.remove(C_COLUMNA_ID);

            //
            // Actualizamos el registro con el identificador que hemos extraido
            //
            result = db.update(C_TABLA, reg, "_id=" + id, null);
        }
        return result;
    }

    /**
     * Comprueba si existe el registro
     */
    public boolean exists(long id) throws SQLException
    {
        boolean exists ;

        if (db == null)
            abrir();

        Cursor c = db.query( true, C_TABLA, columnas, C_COLUMNA_ID + "=" + id, null, null, null, null, null);

        exists = (c.getCount() > 0);

        c.close();

        return exists;
    }
   

    public ArrayList<Medicina> getMedicinas(String filtro)
    {
        ArrayList<Medicina> medicinas = new ArrayList<Medicina>();

        if (db == null)
            abrir();

        Cursor c = db.query(true, C_TABLA, columnas, filtro, null, null, null, null, null);

        for(c.moveToFirst(); !c.isAfterLast(); c.moveToNext())
        {
        	
            medicinas.add(Medicina.cursorToMedicina(contexto, c));
        }

        c.close();

        return medicinas;
    }
   
    public ArrayList<Medicina> getMedicinasCantidades(String filtro)
    {
        ArrayList<Medicina> medicinas = new ArrayList<Medicina>();

        if (db == null)
            abrir();
         Cursor c = db.query(true, C_TABLA, columnas, filtro, null, null, null, C_COLUMNA_CANTIDAD, null);

        for(c.moveToFirst(); !c.isAfterLast(); c.moveToNext())
        {
            medicinas.add(Medicina.cursorToMedicina(contexto, c));
        }

        c.close();

        return medicinas;
    }



}
