package modelo;
import android.content.ContentValues;
import android.content.Context;
import android.content.CursorLoader;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;
import bbdd.PillControlDbHelper;

import java.util.ArrayList;






public class PerfilDbAdapter {

	//
	// Definimos constante con el nombre de la tabla
	//
	public static final String C_TABLA = "PERFIL" ;
	
    //
    // Definimos constantes con el nombre de las columnas de la tabla
    //
    public static final String C_COLUMNA_ID	= "_id";
    public static final String C_COLUMNA_NOMBRE = "hip_nombre";
    public static final String C_COLUMNA_FNACIMIENTO = "hip_fnacimiento";
    public static final String C_COLUMNA_EDAD = "hip_edad";
    public static final String C_COLUMNA_USUARIO = "hip_usuario";
    public static final String C_COLUMNA_PASSWD = "hip_passwd";
    private Context contexto;
    private PillControlDbHelper dbHelper;
    private SQLiteDatabase db;

    //
    // Definimos lista de columnas de la tabla para utilizarla en las consultas a la base de datos
    //
    private String[] columnas = new String[]{
            C_COLUMNA_ID,
            C_COLUMNA_NOMBRE,
            C_COLUMNA_FNACIMIENTO,
            C_COLUMNA_EDAD,
            C_COLUMNA_USUARIO,
            C_COLUMNA_PASSWD,
                       
    };
	public PerfilDbAdapter(Context context)
	{
		this.contexto = context;
	}

	public PerfilDbAdapter abrir() throws SQLException
	{
		 
		
		dbHelper = new PillControlDbHelper(contexto);
		
	
		db = dbHelper.getWritableDatabase();
	
		
		return this;
	}

	public void cerrar()
	{
		dbHelper.close();
	}

	
    /**
     * Devuelve cursor con todos los registros y columnas de la tabla
     */
    public Cursor getCursor(String filtro) throws SQLException {

        if (db == null)
        abrir();
        Cursor c;
try {        c = db.query(true, C_TABLA, columnas, filtro, null, null, null, null, null);
 }finally {
	 //casca
 }
        return c;
    }
	
	/**
	 * Devuelve cursor con todos las columnas del registro
	 */
	public Cursor getRegistro(long id) throws SQLException
	{
	;
        if (db == null){
        	
          abrir();
        }
    
        Cursor c = db.query( true, C_TABLA, columnas, C_COLUMNA_ID + "=" + id, null, null, null, null, null);
      
        
		//Nos movemos al primer registro de la consulta
		if (c != null) {
			c.moveToFirst();
		}
		return c;
	}
	
	/**
	 * Inserta los valores en un registro de la tabla
	 */
	public long insert(ContentValues reg)
	{
		if (db == null)
			abrir();
		
		return db.insert(C_TABLA, null, reg);
	}
	
	/**
	 * Eliminar el registro con el identificador indicado
	 */
	public long delete(long id)
	{
		if (db == null)
	 abrir();
		
		return db.delete(C_TABLA, "_id=" + id, null);
	}
	
    /**
     * Modificar el registro
     */
    public long update(ContentValues reg)
    {
        long result = 0;

        if (db == null)
            abrir();

        if (reg.containsKey(C_COLUMNA_ID))
        {
            //
            // Obtenemos el id y lo borramos de los valores
            //
            long id = reg.getAsLong(C_COLUMNA_ID);

            reg.remove(C_COLUMNA_ID);

            //
            // Actualizamos el registro con el identificador que hemos extraido
            //
            result = db.update(C_TABLA, reg, "_id=" + id, null);
        }
        return result;
    }

    /**
     * Comprueba si existe el registro
     */
    public boolean exists(long id) throws SQLException
    {
        boolean exists ;

        if (db == null)
            abrir();

        Cursor c = db.query(true, C_TABLA, columnas, C_COLUMNA_ID + "=" + id, null, null, null, null, null);

        exists = (c.getCount() > 0);

        c.close();

        return exists;
    }

    public ArrayList<Perfil> getPerfil(String filtro)
    {
        ArrayList<Perfil> perfiles = new ArrayList<Perfil>();

        if (db == null)
            abrir();

        Cursor c = db.query(true, C_TABLA, columnas, filtro, null, null, null, null, null);
        
        for(c.moveToFirst(); !c.isAfterLast(); c.moveToNext())
        {
        	 
            perfiles.add(Perfil.cursorToPerfil(contexto, c));
        }

        c.close();

        return perfiles;
    }



}
